class TestRecord(object):

    def __init__(self):
        self.test_record_list = list()

    def clean_record(self) -> None:
        self.test_record_list = list()


test_record = TestRecord()
